@@ -3,6 +3,7 @@ import sys
 from collections import deque
 from collections import defaultdict
 import textwrap
+import warnings
 
 from .globals import Globals
 from . import version
@@ -296,6 +297,7 @@ class TaskLoader():
     cmd_options = ()
 
     def __init__(self):
+        warnings.warn('doit.cmd_base.py:TaskLoader is deprecated user TaskLoader2 instead', DeprecationWarning)
         # list of command names, used to detect clash of task names and commands
         self.cmd_names = []
         self.config = None  # reference to config object taken from Command
@@ -384,8 +386,9 @@ class NamespaceTaskLoader(TaskLoader2):
         return loader.load_doit_config(self.namespace)
 
     def load_tasks(self, cmd, pos_args):
-        tasks = loader.load_tasks(self.namespace, self.cmd_names,
-                                 cmd.execute_tasks)
+        tasks = loader.load_tasks(
+            self.namespace, self.cmd_names, allow_delayed=cmd.execute_tasks,
+            args=pos_args, config=self.config)
 
         # Add task options from config, if present
         if self.config is not None:
@@ -464,6 +467,7 @@ class DoitCmdBase(Command):
     def __init__(self, task_loader, cmds=None, **kwargs):
         super(DoitCmdBase, self).__init__(**kwargs)
         self.sel_tasks = None # selected tasks for command
+        self.sel_default_tasks = True # False if tasks were specified from command line
         self.dep_manager = None #
         self.outstream = sys.stdout
         self.loader = task_loader
@@ -544,7 +548,6 @@ class DoitCmdBase(Command):
         :param params: instance of cmdparse.DefaultUpdate
         :param args: list of string arguments (containing task names)
         """
-
         # distinguish legacy and new-style task loader API when loading tasks:
         legacy_loader = getattr(self.loader, 'API', 1) < 2
         if legacy_loader:
@@ -560,6 +563,7 @@ class DoitCmdBase(Command):
         self.check_minversion(params.get('minversion'))
 
         # set selected tasks for command
+        self.sel_default_tasks = len(args) == 0
         self.sel_tasks = args or params.get('default_tasks')
 
         CmdAction.STRING_FORMAT = params.get('action_string_formatting', 'old')
@@ -605,11 +609,13 @@ class DoitCmdBase(Command):
 # helper functions to find list of tasks
 
 
-def check_tasks_exist(tasks, name_list):
+def check_tasks_exist(tasks, name_list, skip_wildcard=False):
     """check task exist"""
     if not name_list:
         return
     for task_name in name_list:
+        if skip_wildcard and '*' in task_name:
+            continue
         if task_name not in tasks:
             msg = "'%s' is not a task."
             raise InvalidCommand(msg % task_name)
